#include <Wire.h>
#include <PCM.h>
#include <Math.h>
#include "sounds.h"

const int MPU1 = 0x1D;
const int MPU2 = 0x53;
int16_t s1x, s1y, s1z;
int16_t s2x, s2y, s2z;

bool moving = false;

void getCoords(const int MPU) {
  Wire.beginTransmission(MPU);
  Wire.write(0x32);
  Wire.endTransmission(false);
  Wire.requestFrom(MPU, 6, true);

  // accelerometer has 8 bits, and the values are 16, so we get the lower and higher bits
  if(MPU == 0x1D) {
    s1x = Wire.read() << 8 | Wire.read();
    s1y = Wire.read() << 8 | Wire.read();
    s1z = Wire.read() << 8 | Wire.read();

  }
  else {
    s2x = Wire.read() << 8 | Wire.read();     
    s2y = Wire.read() << 8 | Wire.read();  
    s2z = Wire.read() << 8 | Wire.read(); 

  }

}

void checkToPlay(int16_t lastX){
  if(lastX == s1x) {
    int16_t prev_s1x = s1x;
    int16_t prev_s1y = s1y;
    int16_t prev_s1z = s1z;
  
    getCoords(MPU1);
    double dist = sqrt(pow(prev_s1x - s1x, 2) + pow(prev_s1y - s1y, 2) + pow(prev_s1z - s1z, 2));
  
    if (dist > 22000) {
      moving = true;
    }
    if (dist < 2000 && moving) {
      moving = false;
      long r = random(2);
      if(r == 0)
        startPlayback(s1_sound0, sizeof(s1_sound0));
      else
        startPlayback(s1_sound1, sizeof(s1_sound1));
    }
  }
  else {
    int16_t prev_s2x = s2x;
    int16_t prev_s2y = s2y;
    int16_t prev_s2z = s2z;
  
    getCoords(MPU2);
  
    double dist = sqrt(pow(prev_s2x - s2x, 2) + pow(prev_s2y - s2y, 2) + pow(prev_s2z - s2z, 2));
  
    if (dist > 22000) {
      moving = true;
    }
  
    if (dist < 2000 && moving) {
      moving = false;
      long r = random(2);
      if(r == 0)
        startPlayback(s2_sound0, sizeof(s2_sound0));
      else
        startPlayback(s2_sound1, sizeof(s2_sound1));
      }
  }
 
}


void setup(){
  Wire.begin();
  Wire.beginTransmission(MPU1);
  // starts accelerometer
  Wire.write(0x2D);  
  Wire.write(8);
  // lower sensitivity
  Wire.write(0x31);
  Wire.write(3);
  Wire.endTransmission(true);
  
  Wire.begin();
  Wire.beginTransmission(MPU2);
  Wire.write(0x2D);  
  Wire.write(8);
  Wire.write(0x31);
  Wire.write(3);
  Wire.endTransmission(true);

  getCoords(MPU1);
  getCoords(MPU2);
}


void loop(){
  checkToPlay(s1x);
  checkToPlay(s2x);
}
